# ApplicationDynamicConfig

Application dynamic configuration that is generated by the backend API service. This applies business rule configuration based on how the application is configured by the user and its services. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**service_routes** | [**[ApplicationServiceRoute]**](ApplicationServiceRoute.md) | A list of service routes used to map services from an internal name to an external name, as defined by the expose_type of the ApplicationServiceAssignment.  This is provided as a separate list, dynamic generated, provided to the application, since the routing rules may be required for the main webapp.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


